You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@daffodil.apache.org by sl...@apache.org on 2020/09/30 11:42:32 UTC

[incubator-daffodil] branch master updated: Replace NoRep terminology with InputValueCalc

This is an automated email from the ASF dual-hosted git repository.

slawrence pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-daffodil.git


The following commit(s) were added to refs/heads/master by this push:
     new d3b6350  Replace NoRep terminology with InputValueCalc
d3b6350 is described below

commit d3b635062a396e91f3373b874808e5fce22a5967
Author: IanCarlsonOwl <ic...@tresys.com>
AuthorDate: Mon Sep 28 13:18:33 2020 -0500

    Replace NoRep terminology with InputValueCalc
    
    DAFFODIL-1533
---
 .../apache/daffodil/grammar/primitives/ElementCombinator.scala    | 8 ++++----
 .../apache/daffodil/processors/unparsers/ElementUnparser.scala    | 2 +-
 .../apache/daffodil/processors/parsers/ElementCombinator1.scala   | 4 ++--
 3 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/daffodil-core/src/main/scala/org/apache/daffodil/grammar/primitives/ElementCombinator.scala b/daffodil-core/src/main/scala/org/apache/daffodil/grammar/primitives/ElementCombinator.scala
index f2ea93a..fd50d50 100644
--- a/daffodil-core/src/main/scala/org/apache/daffodil/grammar/primitives/ElementCombinator.scala
+++ b/daffodil-core/src/main/scala/org/apache/daffodil/grammar/primitives/ElementCombinator.scala
@@ -24,7 +24,7 @@ import org.apache.daffodil.grammar.Gram
 import org.apache.daffodil.grammar.NamedGram
 import org.apache.daffodil.grammar.Terminal
 import org.apache.daffodil.processors.parsers.ElementParser
-import org.apache.daffodil.processors.parsers.ElementParserNoRep
+import org.apache.daffodil.processors.parsers.ElementParserInputValueCalc
 import org.apache.daffodil.processors.parsers.Parser
 import org.apache.daffodil.processors.parsers.CaptureEndOfContentLengthParser
 import org.apache.daffodil.processors.parsers.CaptureEndOfValueLengthParser
@@ -37,7 +37,7 @@ import org.apache.daffodil.processors.unparsers.CaptureStartOfValueLengthUnparse
 import org.apache.daffodil.processors.unparsers.ElementOVCSpecifiedLengthUnparser
 import org.apache.daffodil.processors.unparsers.ElementOVCUnspecifiedLengthUnparser
 import org.apache.daffodil.processors.unparsers.ElementSpecifiedLengthUnparser
-import org.apache.daffodil.processors.unparsers.ElementUnparserNoRep
+import org.apache.daffodil.processors.unparsers.ElementUnparserInputValueCalc
 import org.apache.daffodil.processors.unparsers.ElementUnspecifiedLengthUnparser
 import org.apache.daffodil.processors.unparsers.ElementUnusedUnparser
 import org.apache.daffodil.processors.unparsers.LeftCenteredPaddingUnparser
@@ -302,7 +302,7 @@ class ElementParseAndUnspecifiedLength(context: ElementBase, eBeforeGram: Gram,
         eRepTypeParser
       )
     else
-      new ElementParserNoRep(
+      new ElementParserInputValueCalc(
         context.erd,
         context.name,
         patDiscrim,
@@ -325,7 +325,7 @@ class ElementParseAndUnspecifiedLength(context: ElementBase, eBeforeGram: Gram,
       // dfdl:inputValueCalc case.
       // This unparser will assume the events are in the event stream, having been inferred and put
       // in place by the next element resolver.
-      new ElementUnparserNoRep(context.erd, uSetVar)
+      new ElementUnparserInputValueCalc(context.erd, uSetVar)
     }
   }
 }
diff --git a/daffodil-runtime1-unparser/src/main/scala/org/apache/daffodil/processors/unparsers/ElementUnparser.scala b/daffodil-runtime1-unparser/src/main/scala/org/apache/daffodil/processors/unparsers/ElementUnparser.scala
index 12f3117..2b92952 100644
--- a/daffodil-runtime1-unparser/src/main/scala/org/apache/daffodil/processors/unparsers/ElementUnparser.scala
+++ b/daffodil-runtime1-unparser/src/main/scala/org/apache/daffodil/processors/unparsers/ElementUnparser.scala
@@ -72,7 +72,7 @@ sealed trait RepMoveMixin {
  * whether to place separators, and there should not be any separator
  * corresponding to an IVC element.
  */
-class ElementUnparserNoRep(
+class ElementUnparserInputValueCalc(
   erd: ElementRuntimeData,
   setVarUnparsers: Array[Unparser])
   extends ElementUnparserBase(
diff --git a/daffodil-runtime1/src/main/scala/org/apache/daffodil/processors/parsers/ElementCombinator1.scala b/daffodil-runtime1/src/main/scala/org/apache/daffodil/processors/parsers/ElementCombinator1.scala
index 2b74ede..ef42e3b 100644
--- a/daffodil-runtime1/src/main/scala/org/apache/daffodil/processors/parsers/ElementCombinator1.scala
+++ b/daffodil-runtime1/src/main/scala/org/apache/daffodil/processors/parsers/ElementCombinator1.scala
@@ -283,7 +283,7 @@ class ElementParser(
   }
 }
 
-class ElementParserNoRep(
+class ElementParserInputValueCalc(
   erd: ElementRuntimeData,
   name: String,
   patDiscrim: Maybe[Parser],
@@ -310,7 +310,7 @@ class ElementParserNoRep(
   // if there is no rep (inputValueCalc), then we do create a new child so that index must advance,
   // but we don't create anything new as far as the group is concerned, and we don't want
   // the group 'thinking' that there's a prior sibling inside the group and placing a
   // separator after it. So in the case of NoRep, we don't advance group child, just element child.
   override def move(state: PState): Unit = {
     state.mpstate.moveOverOneElementChildOnly
   }
@@ -310,7 +310,7 @@ class ElementParserNoRep(
   // but we don't create anything new as far as the group is concerned, and we don't want
   // the group 'thinking' that there's a prior sibling inside the group and placing a
-  // separator after it. So in the case of NoRep, we don't advance group child, just element child.
+  // separator after it. So in the case of InputValueCalc, we don't advance group child, just element child.
   override def move(state: PState): Unit = {
     state.mpstate.moveOverOneElementChildOnly